%global pypi_name jsonpickle
%global py3_prefix python%{python3_pkgversion}

%global with_python3 1

Name:           python-jsonpickle
Version:        0.9.4
Release:        3%{?dist}
Summary:        A module that allows any object to be serialized into JSON

Group:          Development/Languages
License:        BSD
URL:            https://pypi.io/project/jsonpickle/
Source0:        %{pypi_source}
Source1:        %{pypi_source}.asc
# upstream does not indicate which key ids are used to sign releases so this is
# purely "trust on first use":
#    https://github.com/jsonpickle/jsonpickle/issues/310
# gpg2 --recv-keys "FA41 BF59 C1B4 8E8C 5F3D A61C 8CE2 6BF4 A9F6 06B0"
# gpg2 --export --export-options export-minimal "FA41 BF59 C1B4 8E8C 5F3D A61C 8CE2 6BF4 A9F6 06B0" > gpgkey-FA41_BF59_C1B4_8E8C_5F3D_A61C_8CE2_6BF4_A9F6_06B0.gpg
Source2:        gpgkey-FA41_BF59_C1B4_8E8C_5F3D_A61C_8CE2_6BF4_A9F6_06B0.gpg

# the numpy extension code in jsonpickle uses ".tobytes()" which was added in
# numpy 1.9.0 but EPEL 7 ships numpy 1.7.1.
# The methode was added in https://github.com/numpy/numpy/pull/4257 and is just
# an alias for ".tostring()" so just change it.
Patch1:         jsonpickle-numpy-use-tostring.patch

# upstream patch cherry-picked from git commit 8b660902 (part of v0.9.5)
#   https://github.com/jsonpickle/jsonpickle/commit/8b6609023292eade46a43c38aafd6acecbd2f26b
Patch2:         jsonpickle-simplereducehandler-handle-more-than-two-args.patch

%global _docdir_fmt %{name}

BuildArch:      noarch
BuildRequires:  gnupg2


%description
This module allows python objects to be serialized to JSON in a similar fashion
to the pickle module.

%package -n python2-jsonpickle
Summary:        A module that allows any object to be serialized into JSON
%{?python_provide:%python_provide python2-jsonpickle}

BuildRequires:  python2-devel
BuildRequires:  python-simplejson
BuildRequires:  python-feedparser
BuildRequires:  numpy
BuildRequires:  python-enum34
BuildRequires:  python-bson
BuildRequires:  python-demjson
BuildRequires:  python-pytest
Requires:       python-simplejson

%if 0%{?fedora}
# This doesn't exist in EL7 yet...
BuildRequires:  python-ujson
%endif

%description -n python2-jsonpickle
This module allows python objects to be serialized to JSON in a similar fashion
to the pickle module.

This is the version for Python 3.

%if 0%{?with_python3}
%package -n %{py3_prefix}-jsonpickle
Summary:        A module that allows any object to be serialized into JSON
%{?python_provide:%python_provide python3-jsonpickle}

BuildRequires:  %{py3_prefix}-devel
BuildRequires:  %{py3_prefix}-simplejson
# BuildRequires:  python3-feedparser
BuildRequires:  %{py3_prefix}-numpy
BuildRequires:  %{py3_prefix}-bson
# https://bugzilla.redhat.com/show_bug.cgi?id=1238787
# BuildRequires:  python3-ujson
# BuildRequires:  python3-demjson
BuildRequires:  %{py3_prefix}-pytest
Requires:       %{py3_prefix}-simplejson


%description -n %{py3_prefix}-jsonpickle
This module allows python objects to be serialized to JSON in a similar fashion
to the pickle module.

This is the version for Python 3.
%endif

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1 -n %{pypi_name}-%{version}
rm -r *.egg-info


%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif


%install
%py2_install
%if 0%{?with_python3}
%py3_install
%endif


%check
PYTHONPATH=%{buildroot}%{python2_sitelib} py.test
%if 0%{?with_python3}
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test-%{python3_version}
%endif


%files -n python2-jsonpickle
%license COPYING
%{python2_sitelib}/*

%if 0%{?with_python3}
%files -n %{py3_prefix}-jsonpickle
%license COPYING
%{python3_sitelib}/*
%endif

%changelog
* Thu May 14 2020 Felix Schwarz <fschwarz@fedoraproject.org> - 0.9.4-3
- add Python 3 subpackage (rhbz #1828910)
- add source file verification

* Thu Mar 30 2017 Ralph Bean <rbean@redhat.com> - 0.9.4-2
- Conditionalize python3 package for EPEL7 compat.

* Thu Mar 30 2017 Ralph Bean <rbean@redhat.com> - 0.9.4-1
- new version

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.9.3-2
- Rebuild for Python 3.6

* Fri Dec 09 2016 Jon Ciesla <limburgher@gmail.com> - 0.9.3-1
- 0.9.3

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.2-5
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 23 2015 Jon Ciesla <limburgher@gmail.com> - 0.9.2-3
- Disable tests to fix build.

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.2-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jul  2 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.9.2-1
- Update to latest version
- Clean up spec file a bit
- Add python3 subpackage (#1233915)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Aug 07 2013 Jon Ciesla <limburgher@gmail.com> - 0.4.0-1
- Latest upstream release, 0.4.0.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sat Jan 23 2010 Ben Boeckel <MathStuf@gmail.com> - 0.3.1-1
- Update to 0.3.1

* Mon Nov 02 2009 Ben Boeckel <MathStuf@gmail.com> - 0.2.0-1
- Initial package
